@@ -12,6 +12,7 @@ imported as "from pyzolib import xxx"
 The packages currently are:
   * path - object oriented path processing (no more os.path.x)
   * paths - Get paths to useful directories in a cross platform manner.
+  * qt - Proxy for importing QtCore et al. from PySide or PyQt4
   * ssdf - the Simple Structured Data Format (for config files and 
     scientific databases)
   * insertdocs - a sphynx pre-processor to include docstrings in the text,
@@ -20,7 +21,10 @@ The packages currently are:
     environment to establish the location of a gcc compiler.
   * gccutils - used by the above to manage the gcc compiler.
   * interprerers - list the Python interpreters available on this system.
+  * dllutils - utilities to set the RPATH in dynamic libararies and 
+    remove depndencies on the MSVCR from the embedded manifest.
+  * shebang - for making shebangs in pyzo distro absolute.
 
 """
 
-__version__ = '0.2'
+__version__ = '0.3.3'
